package Mentat::Processor::Component::Dummy;
use strict;
use warnings;

#*******************************************************************************
# DOCUMENTATION SECTION
#*******************************************************************************

=head1 NAME

Mentat::Processor::Component::Dummy - Short module description

=head1 SYNOPSIS

 use Mentat::Processor::Component::Dummy;

=head1 DESCRIPTION

Extensive module description

=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1), Mentat::Processor::Component(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
# LIBRARY LOADING SECTION
#*******************************************************************************

#-- Perl core modules ---------------------------------------------------------#
use Carp;
use Scalar::Util 'blessed';

#use Data::Dumper; #-+-> DEVEL ONLY <-+-#
#use Smart::Comments; #-+-> DEVEL ONLY <-+-#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Mentat::Processor::Component;

#*******************************************************************************
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
# INITIALIZATION AND CLEANUP SECTION
#*******************************************************************************

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL @ISA);
    $VERSION = '0.1';
    $DEVEL   = 0;
    @ISA     = ('Mentat::Processor::Component');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
# IMPLEMENTATION SECTION
#*******************************************************************************

sub eha() {
	### eha: @_
	return 1;
}
sub ehb() {
	### ehb: @_
	return 1;
}
sub ehc() {
	### ehc: @_
	return 1;
}
sub ehd() {
	### ehd: @_
	return 1;
}
sub ehe() {
	### ehe: @_
	return 1;
}
sub ehf() {
	### ehf: @_
	return 1;
}
sub eh1() {
	### eh1: @_
	return 1;
}
sub eh2() {
	### eh2: @_
	return 1;
}
sub eh3() {
	### eh3: @_
	return 1;
}
sub eh4() {
	### eh4: @_
	return 1;
}
sub eh5() {
	### eh5: @_
	return 1;
}
sub eh6() {
	### eh6: @_
	return 1;
}
sub signal_usr1() {
	### signal_usr1: @_
	return 1;
}
sub signal_usr2() {
	### signal_usr2: @_
	return 1;
}

=item component_attached($$) [PUBLIC]

  Usage     : $instance->component_attached($requested_component, $specification);
  Purpose   : Allow the component to react to attachment of other components
  Arguments : Mentat::Processor::Component $component - component, that was attached
              STRING $specification - specification of the attached component
  Returns   : Nothing
  Throws    : Croaks, if not invoked on instance or given invalid arguments
              Dies, in case of some problems with other component
  Comment   : Called during Mentat::Processor`s bootstrap phase

=cut

sub component_attached($$)
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless blessed($self);
	my ($component, $specification) = @_;

	my $str = "C".$self->id.": Atttached ".$component->spec.":".$component->id.", requested $specification";
	die "$str (FAILED)\n" if $self->{fail_attach};
	### [A]: $str
}

=item check() [PUBLIC]

  Usage     : $instance->check();
  Purpose   : Allow the component to perform last check before startup
  Arguments : None
  Returns   : Nothing
  Throws    : Croaks, if not invoked on instance or given invalid arguments
              Dies in case of some problems with component configuration

=cut

sub check()
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless blessed($self);

	my $str = "C".$self->id.": Checked";
	die "$str (FAILED)\n" if $self->{fail_check};
	### [C]: $str
}

#-------------------------------------------------------------------------------
# Private interface
#-------------------------------------------------------------------------------

# _init(%) [PROTECTED]
#
#  Usage     : return $self->_init(@_);
#  Purpose   : Initialize the new Mentat::Processor::Component instance
#  Arguments : HASH %config - component configurations
#  Returns   : Mentat::Processor::Component reference
#  Throws    : Croaks, if not invoked on instance
#  Comments  : This method must never be called directly, it is supposed to be overloaded by subclasses.

sub _init(%)
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless blessed($self);
	my %config = @_;
	foreach my $cfg (keys %config) {
		$self->{$cfg} = $config{$cfg};
	}
	return $self;
}

# _get_events_emitted() [PROTECTED]
#
#  Usage     : Used as a hook method from template method register()
#  Purpose   : Return list of events emitted by this component
#  Arguments : None
#  Returns   : ARRAY REFERENCE $events containing event names as STRINGS
#  Throws    : Croaks, if not invoked on instance

sub _get_events_emitted()
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless blessed($self);
	return $self->{emitted} if ref $self->{emitted} eq 'ARRAY';
	return [];
}

# _get_events_handled() [PROTECTED]
#
#  Usage     : Used as a hook method from template method register()
#  Purpose   : Return list of events and appropriate handlers for this component
#  Arguments : None
#  Returns   : ARRAY REFERENCE $handlers with internal structure [$event, $handler]
#                  STRING $event   - event name
#                  STRING $handler - event handler name
#  Throws    : Croaks, if not invoked on instance

sub _get_events_handled()
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless blessed($self);
	return $self->{handled} if ref $self->{handled} eq 'ARRAY';
	return [];
}

# _get_components_linked() [PROTECTED]
#
#  Usage     : Used as a hook method from template method register()
#  Purpose   : Return list of required components
#  Arguments : None
#  Returns   : ARRAY REFERENCE $components containing STRINGS with following format:
#                  'type'      - request for component of given type and any name
#                  ':name'     - request for component of any type but given name
#                  'type:name' - request for component of given both type and name
#  Throws    : Croaks, if not invoked on instance

sub _get_components_linked()
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless blessed($self);
	return $self->{linked} if ref $self->{linked} eq 'ARRAY';
	return [];
}

=pod

=back

=cut

1;
